// Fig. 23.8: Browser.cs
// WebBrowser control example.
using System;
using System.Windows.Forms;

public partial class BrowserForm : Form
{
   public BrowserForm()
   {
      InitializeComponent();
   } // end constructor

   // navigate back one page
   private void backButton_Click( object sender, EventArgs e )
   {
      webBrowser.GoBack();
   } // end method backButton_Click

   // navigate forward one page
   private void forwardButton_Click( object sender, EventArgs e )
   {
      webBrowser.GoForward();
   } // end method forwardButton_Click

   // stop loading the current page
   private void stopButton_Click( object sender, EventArgs e )
   {
      webBrowser.Stop();
   } // end method stopButton_Click

   // reload the current page
   private void reloadButton_Click( object sender, EventArgs e )
   {
      webBrowser.Refresh();
   } // end method reloadButton_Click

   // navigate to the user's home page
   private void homeButton_Click( object sender, EventArgs e )
   {
      webBrowser.GoHome();
   } // end method homeButton_Click

   // if the user pressed enter, navigate to the specified URL
   private void navigationTextBox_KeyDown( object sender, 
      KeyEventArgs e )
   {
      if ( e.KeyCode == Keys.Enter )
         webBrowser.Navigate( navigationTextBox.Text );
   } // end method navigationTextBox_KeyDown

   // enable stopButton while the current page is loading
   private void webBrowser_Navigating( object sender, 
      WebBrowserNavigatingEventArgs e )
   {
      stopButton.Enabled = true;
   } // end method webBrowser_Navigating

   // update the status text
   private void webBrowser_StatusTextChanged( object sender, 
      EventArgs e )
   {
      statusTextBox.Text = webBrowser.StatusText;
   } // end method webBrowser_StatusTextChanged

   // update the ProgressBar for how much of the page has been loaded 
   private void webBrowser_ProgressChanged( object sender, 
      WebBrowserProgressChangedEventArgs e )
   {
      pageProgressBar.Value =
         ( int ) ( ( 100 * e.CurrentProgress ) / e.MaximumProgress );
   } // end method webBrowser_ProgressChanged

   // update the web browser's controls appropriately
   private void webBrowser_DocumentCompleted( object sender, 
      WebBrowserDocumentCompletedEventArgs e )
   {
      // set the text in navigationTextBox to the current page's URL
      navigationTextBox.Text = webBrowser.Url.ToString();
   
      // enable or disable backButton and forwardButton
      backButton.Enabled = webBrowser.CanGoBack;
      forwardButton.Enabled = webBrowser.CanGoForward;

      // disable stopButton
      stopButton.Enabled = false;

      // clear the pageProgressBar
      pageProgressBar.Value = 0;
   } // end method webBrowser_DocumentCompleted

   // update the title of the Browser
   private void webBrowser_DocumentTitleChanged( object sender, 
      EventArgs e )
   {
      this.Text = webBrowser.DocumentTitle + " - Browser";
   } // end method webBrowser_DocumentTitleChanged
} // end class BrowserForm

/**************************************************************************
 * (C) Copyright 1992-2006 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/